from setuptools import setup, find_packages

setup(
    name='dsalibpy',
    version='0.3',
    packages=find_packages(),
    description='A library for fundamental and advanced data structures',
    author='Yashodeep Basnet',
    author_email='yyashodeep.basnet@gmail.com',
    url='https://github.com/yasho11/Py_dsalib.git',
    install_requires=[],
)
